/*
gcc -Wall %1.c -o %1.exe 
   */
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#define MAXIT 100
#define EPS 3.0e-7
#define FPMIN 1.0e-30

double betai(double a, double b, double x);
double betacf(double a, double b, double x);
double gammln(double xx);

int main(void)
{
/* From Gore OLS -- Beta on South, SE, t, prob,
 * -3.357468   .8105734    -4.14   0.000
 * , df = 424
 * Beta on Income
 *  -.0166081   .0462757    -0.36   0.720*/
	double v=424, a, b, x, t, tinvprob;
	a = v/2.0;
	b = 0.5;
//	t = -4.14;
	t = -.0166081/0.0462757;
	x = v/(v+t*t);
	tinvprob = betai(a, b, x);
	printf(" Inverse Probability = %f",tinvprob);
	return(0);
}
/* End of Main Program */

double betai(double a, double b, double x)
{
	double betacf(double a, double b, double x);
	double gammln(double xx);
//	void nrerror(char error_text[]);
	double bt;

	if (x < 0.0 || x > 1.0)
	{
		printf("Bad x in routine betai");
		exit(EXIT_FAILURE);
	}
	if (x == 0.0 || x == 1.0) bt=0.0;
	else
		bt=exp(gammln(a+b)-gammln(a)-gammln(b)+a*log(x)+b*log(1.0-x));
	if (x < (a+1.0)/(a+b+2.0))
		return bt*betacf(a,b,x)/a;
	else
		return 1.0-bt*betacf(b,a,1.0-x)/b;
}

double betacf(double a, double b, double x)
{
//	void nrerror(char error_text[]);
	int m,m2;
	double aa,c,d,del,h,qab,qam,qap;

	qab=a+b;
	qap=a+1.0;
	qam=a-1.0;
	c=1.0;
	d=1.0-qab*x/qap;
	if (fabs(d) < FPMIN) d=FPMIN;
	d=1.0/d;
	h=d;
	for (m=1;m<=MAXIT;m++) {
		m2=2*m;
		aa=m*(b-m)*x/((qam+m2)*(a+m2));
		d=1.0+aa*d;
		if (fabs(d) < FPMIN) d=FPMIN;
		c=1.0+aa/c;
		if (fabs(c) < FPMIN) c=FPMIN;
		d=1.0/d;
		h *= d*c;
		aa = -(a+m)*(qab+m)*x/((a+m2)*(qap+m2));
		d=1.0+aa*d;
		if (fabs(d) < FPMIN) d=FPMIN;
		c=1.0+aa/c;
		if (fabs(c) < FPMIN) c=FPMIN;
		d=1.0/d;
		del=d*c;
		h *= del;
		if (fabs(del-1.0) < EPS) break;
	}
	if (m > MAXIT)
	{
		printf("a or b too big, or MAXIT too small in betacf");
		exit(EXIT_FAILURE);
	}
	return h;
}
double gammln(double xx)
{
	double x,y,tmp,ser;
	static double cof[6]={76.18009172947146,-86.50532032941677,
	24.01409824083091,-1.231739572450155,
	0.1208650973866179e-2,-0.5395239384953e-5};
	int j;

	y=x=xx;
	tmp=x+5.5;
	tmp -= (x+0.5)*log(tmp);
	ser=1.000000000190015;
	for (j=0;j<=5;j++) ser += cof[j]/++y;
	return -tmp+log(2.5066282746310005*ser/x);
}

